# modul pribadi -> convert code python menyerupai php

[![Youtobe: iewil](https://img.shields.io/youtube/channel/subscribers/UCvBSqRaT6nsPvtl8m6GaQpg?style=social)](https://youtube.com/c/iewil)
[![Github: iewil](https://img.shields.io/github/followers/iewilmaestro?style=social)](https://github.com/iewilmaestro)
[![Telegram: iewil](https://img.shields.io/badge/Telegram-Iewil-green?style=social&logo=Telegram)](https://t.me/iewil57)
<br>

### Modul sebelum instalasi
```
$ pkg update && pkg upgrade
$ pkg install python
```

### Instalasi
```py
pip install iewil
```
### Download
https://pypi.org/project/iewil/0.0.4

### Fitur
- [x] Banner(title,versi)
    - banner pribadi
- [x] Line()
- [x] Echo(message,eror = False)
    - jika eror = false maka print message warna hijau
    - jika error = true maka print message warna merah 
- [x] Simpan(filename)
- [x] Timer(seconds)
    - isi seconds dengan waktu dalam detik
- [ ] Explode
- [ ] Curl

### Contoh
```py
from iewil import Timer
Timer(60) # in seconds
```

### License
This software is licensed under MIT License.

### Contribution
I would be happy to receive issues and pull requests. Please provide the problem in details if you have an issue to be submitted.

![Donation: iewil](https://img.shields.io/badge/💰-Donation-blue?style=flat-square)<br>
![BTC: iewil](https://img.shields.io/badge/BTC-18jswG2t9EZrnHju5dyiYw1yGbkcrTSgJg-blue?style=flat-square&logo=bitcoin)
![Paypal: iewil](https://img.shields.io/badge/Paypal-Purna.iera@gmail.com-blue?style=flat-square&logo=paypal)
![Dana: iewil](https://img.shields.io/badge/Dana-085819008551-blue?style=flat-square&logo=idr)
